#################################################################################
# Created       : Martin Foster
# Modified      : 26-Aug-2006
#################################################################################
#
# Spacing - Lesser used module used for the admin and supervisory scripts.
# Copyright (C) 2000-2006  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 3456 Wolfe Cres
#                 Halifax, Nova Scotia
#                 B3L 3S2
#
#################################################################################

package Ethereal::Spacing;					# Package name

use strict;							# Anal retentive check for variables


#################################################################################
# Sub-Routines
#################################################################################

#####################
# Constructor
#
# Allows to class to be exported and thus spawn objects as a result

sub new
{
	#####################
	# Data Members
	my $class    = shift;					# Self reference
	my $limit    = shift;					# Limiting size

	# Setup hash
	my $self = { 
		SIZE  => 0,					# Stored handle
		LIMIT => $limit					# Stored handle
	};

	# Bless $self into designated class
	bless $self, $class;

	# Return self
	return $self;
}

#####################
# Spacing
#
# Nothing over complex in this case, uses known information to know if a
# specific character must be inserted to force spacing in the menu
# structure.

sub Get
{
	#####################
	# Data members
	my $self   = shift;					# Self reference
	my $word   = shift;					# Word to compare

	my $limit  = $self->{'LIMIT'};				# What to push at
	my $size   = $self->{'SIZE'};				# Current size

	my $next;						# Next determined size
	my $pass;						# Return value
	
	#####################
	# Program area
	
	# What will it be next
	$next = $size + length($word);

	# Return
	# Determine return
	$pass = (int($size / $limit) < int($next / $limit))
	  ? '<br>'
	  : '';

	# Set for next pass
	$self->{'SIZE'} = $next;
	  
	return $pass;	
}

1;								# Return true
